@@ -77,23 +77,21 @@ setMethod("plot", "gMCPResult",
 			# TODO Show visualization of graph			
 		})
 
-#options(warn=-1)
-#if (!require("graph")) {
-#	options(warn=0)
-	setGeneric("getNodes", function(object, ...) standardGeneric("getNodes"))
-	setGeneric("setEdge", function(from, to, graph, weights) standardGeneric("setEdge"))
-	setGeneric("edgeAttr", function(self, from, to, attr) standardGeneric("edgeAttr"))
-	setGeneric("edgeAttr<-", function(self, from, to, attr, value) standardGeneric("edgeAttr<-"))
-	setGeneric("nodeAttr", function(self, n, attr) standardGeneric("nodeAttr"))
-	setGeneric("nodeAttr<-", function(self, n, attr, value) standardGeneric("nodeAttr<-"))
-#}
-#options(warn=0)
+setGeneric("getNodes", function(object, ...) standardGeneric("getNodes"))
 
 setMethod("getNodes", c("graphMCP"),
 		function(object, ...) {			
 			return(rownames(object@m))
 		})
 
+setGeneric("getMatrix", function(object, ...) standardGeneric("getMatrix"))
+
+setMethod("getMatrix", c("graphMCP"),
+		function(object, ...) {
+			m <- object@m
+			return(m)
+		})
+
 setGeneric("getWeights", function(object, node, ...) standardGeneric("getWeights"))
 
 setMethod("getWeights", c("graphMCP"),
@@ -123,6 +121,8 @@ setMethod("getWeights", c("gMCPResult"),
 			return(getWeights(graph, node))
 		})
 
+setGeneric("setEdge", function(from, to, graph, weights) standardGeneric("setEdge"))
+
 setMethod("setEdge", signature=signature(from="character", to="character",
 				graph="graphMCP", weights="character"),
 		function(from, to, graph, weights) {
@@ -137,6 +137,9 @@ setMethod("setEdge", signature=signature(from="character", to="character",
 			graph
 		})
 
+setGeneric("edgeAttr", function(self, from, to, attr) standardGeneric("edgeAttr"))
+setGeneric("edgeAttr<-", function(self, from, to, attr, value) standardGeneric("edgeAttr<-"))
+
 setMethod("edgeAttr", signature(self="graphMCP", from="character", to="character",
 				attr="character"),
 		function(self, from, to, attr) {
@@ -152,6 +155,9 @@ setReplaceMethod("edgeAttr",
 			self
 		})
 
+setGeneric("nodeAttr", function(self, n, attr) standardGeneric("nodeAttr"))
+setGeneric("nodeAttr<-", function(self, n, attr, value) standardGeneric("nodeAttr<-"))
+
 setMethod("nodeAttr", signature(self="graphMCP", n="character", attr="character"),
 		function(self, n, attr) {
 			self@nodeAttr[[attr]][n]
