@@ -44,7 +44,7 @@ public class RControl {
 					System.getProperty("eclipse") == null && !debug,
 					System.getProperty("eclipse") != null || debug,
 					new ApplicationLog());
-			ErrorHandler.init("rohmeyer@small-projects.de", "http://www.algorithm-forge.com/report/bugreport.php", true, true, ErrorDialogSGTK.class);
+			ErrorHandler.init("rohmeyer@small-projects.de", "http://www.algorithm-forge.com/report/bugreport.php", true, true, ErrorDialogGMCP.class);
 
 		}
 		Rengine rengine = Rengine.getMainEngine();
@@ -59,7 +59,10 @@ public class RControl {
 		}
 		try {
 			rcs = new RCallServicesREngine(new JRIEngine(rengine));
-			if (System.getProperty("eclipse") != null) {		
+			if (System.getProperty("eclipse") != null) {
+				if (System.getProperty("libPath") != null) {
+					rcs.eval(".libPaths(new=\""+System.getProperty("libPath")+"\")");
+				}
 				rcs.eval("require(gMCP)");				
 				rcs.eval("graph <- BonferroniHolm(3)");
 				rcs.eval("graph2 <- BretzEtAl2011()");
